@@ -2,10 +2,34 @@ import re
 import copy
 import xml.etree.ElementTree as etree
 
+from markdown.preprocessors import Preprocessor
 from markdown.treeprocessors import Treeprocessor
 from markdown.postprocessors import Postprocessor
 
 
+class BackslashPreProcessor(Preprocessor):
+
+	def run(self, lines):
+		new_lines = []
+		codeblock = False
+
+		for line in lines:
+			line = line.replace('>>>', '') # BUG '&gt;&gt;&gt;'
+
+			if line.startswith('```'):
+				codeblock = not codeblock
+
+			else:
+
+				if codeblock:
+					line = '    ' + line
+
+				new_lines.append(line)
+
+		print(new_lines)
+		return new_lines
+
+
 class BackslashTreeProcessor(Treeprocessor):
 
 	def run(self, root):
@@ -33,16 +57,16 @@ class BackslashTreeProcessor(Treeprocessor):
 
 			# Headers
 			elif element.tag in ['h1', 'h2', 'h3', 'h4', 'h5', 'h6']:
-				item = etree.Element('li')
-				header = etree.SubElement(item, element.tag, attrib=element.attrib)
-				header.text = element.text
-				header.tail = ''
-				item.tail = '\n'
-				elements.append(item)
+				element.tail = ''
 				line = etree.Element('li')
+				line.append(element)
 				line.tail = '\n'
 				elements.append(line)
 
+				new_line = etree.Element('li')
+				new_line.tail = '\n'
+				elements.append(new_line)
+
 			# Blockquotes
 			elif element.tag == 'blockquote':
 				first = True
